searchData={"items":[{"type":"module","title":"AshUlid","doc":"Helpers for working with ULIDs.","ref":"AshUlid.html"},{"type":"function","title":"AshUlid.generate/0","doc":"Generate a Crockford Base32 encoded ULID string with current time.","ref":"AshUlid.html#generate/0"},{"type":"function","title":"AshUlid.generate/1","doc":"Generate a Crockford Base32 encoded ULID string with a provided Unix timestamp.","ref":"AshUlid.html#generate/1"},{"type":"function","title":"AshUlid.generate_binary/0","doc":"Generate a binary ULID with current time.","ref":"AshUlid.html#generate_binary/0"},{"type":"function","title":"AshUlid.generate_binary/1","doc":"Generate a binary ULID with a provided Unix timestamp.","ref":"AshUlid.html#generate_binary/1"},{"type":"type","title":"AshUlid.raw/0","doc":"A raw binary representation of a ULID.","ref":"AshUlid.html#t:raw/0"},{"type":"type","title":"AshUlid.t/0","doc":"A Crockford Base32 encoded ULID string.","ref":"AshUlid.html#t:t/0"},{"type":"module","title":"AshUlid.Extension","doc":"`Spark.Dsl.Extension` which adds `ulid_primary_key` to `attributes` section of `Ash.Resource`.","ref":"AshUlid.Extension.html"},{"type":"module","title":"AshUlid.Type","doc":"`Ash.Type` implementation for ULID.","ref":"AshUlid.Type.html"},{"type":"extras","title":"Guide","doc":"# AshUlid\n\n[![Module Version](https://img.shields.io/hexpm/v/ash_ulid)](https://hex.pm/packages/ash_ulid)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen)](https://hexdocs.pm/ash_ulid/)\n[![License](https://img.shields.io/hexpm/l/ash_ulid)](https://github.com/vonagam/ash_ulid/blob/master/LICENSE.md)\n\n`Ash.Type` implementation for [ULID](https://github.com/ulid/spec).\n\nConsists of three modules:\n\n- `AshUlid` - utility functions to generate ULIDs.\n- `AshUlid.Type` - `Ash.Type` implementation.\n- `AshUlid.Extension` - `ulid_primary_key` shortcut.","ref":"readme.html"},{"type":"extras","title":"Installation - Guide","doc":"Add to the deps, get deps (`mix deps.get`), compile them (`mix deps.compile`).\n\n```elixir\ndef deps do\n  [\n    {:ash_ulid, \"~> 0.2.1\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Guide","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Primary key - Guide","doc":"To use as a primary key in `Ash.Resource` it is recommended to add `AshUlid.Extension` that provides `ulid_primary_key`:\n\n```elixir\ndefmodule Example.Resource do\n  use Ash.Resource,\n    extensions: [AshUlid.Extension]\n\n  attributes do\n    ulid_primary_key :id\n  end\nend\n```\n\nWhich is a shortcut for this:\n\n```elixir\nuuid_primary_key :id, type: AshUlid.Type, default: &AshUlid.generate/0\n```\n\nTo prevent formatter from adding parens to `ulid_primary_key` add `:ash_ulid` to `import_deps` in `.formatter.exs`.\n\nIf you plan to use ULID as a main type for primary keys it makes sense to set it as `default_belongs_to_type` in a config:\n\n```elixir\nconfig :ash, default_belongs_to_type: AshUlid.Type\n```\n\n#","ref":"readme.html#primary-key"},{"type":"extras","title":"Attribute type - Guide","doc":"`AshUlid.Type` can be registered under `ulid` name in a config:\n```elixir\nconfig :ash, custom_types: [ulid: AshUlid.Type]\n```\n\nAnd then used like this:\n```elixir\ndefmodule Example.Another do\n  use Ash.Resource\n\n  attributes do\n    attribute :key, :ulid\n  end\n\n  relationships do\n    belongs_to :resource, Example.Resource, attribute_type: :ulid\n  end\nend\n```\n\nWithout an alias it is the same, just replace `:ulid` with `AshUlid.Type`.\n\nIf `default_belongs_to_type` is set then `attribute_type: :ulid` in this example is not needed.\n\n#","ref":"readme.html#attribute-type"},{"type":"extras","title":"Generate - Guide","doc":"To generate ULID call `AshUlid.generate/0` or `AshUlid.generate/1` with a specific timestamp.","ref":"readme.html#generate"},{"type":"extras","title":"References - Guide","doc":"ULID spec can be found [here](https://github.com/ulid/spec).\n\nThe work is mostly based on [`Ecto.ULID`](https://github.com/TheRealReal/ecto-ulid).","ref":"readme.html#references"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2023 Dmitry Maganov\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}